# Hotelling T Independent Samples

# Install R packages and load library of functions

install.packages("ICSNP")
install.packages("mvtnorm")
library(ICSNP) 
library (mvtnorm)

# Assign data to two matrices with different number of subjects
# Assign data to matrix for group membership variable, grp
# Print out the matrices

roger = matrix(c(1,3,2,3,7,2),3,2)
adler = matrix(c(4,6,6,5,5,4,6,8,8,10,10,6),6,2)
grp = matrix(c(1,1,1,2,2,2,2,2,2),9,1)
roger
adler
grp

# Use attach () function so variable names can be used
# Use factor() function to declare group variable as categorical
# Select p-value to print in decimal rather than scientific notation  

Y = data.frame(rbind(roger,adler))
names(Y) = c("effect","satis")
attach(Y)
factor(grp)
options(scipen=999)
Y

# Print out means and standard deviations for two dependent variables


cor(effect,satis)
mean(effect);sd(effect)
mean(satis);sd(satis)

# Install and load R gplots package
# Graph individual group dependent variable means

install.packages("gplots")
library(gplots)
group = data.frame(grp)
Yall= data.frame(group,Y)
par(mfrow = c(2, 1))
plotmeans(effect ~ grp,data=Yall,ylim=c(0,10),xlab="Groups",legends=c("Rogerian","Adlerian"),main ="Counseling Effectiveness",connect=FALSE,mean.labels=TRUE,col=NULL,p=1.0)
plotmeans(satis ~ grp,data=Yall,ylim=c(0,10),xlab="Groups",legends=c("Rogerian","Adlerian"),main ="Counseling Satisfaction",connect=FALSE,mean.labels=TRUE,col=NULL,p=1.0)

# Install and load R biotools package
# Declare grp as factor variable
# Use Y data set and grp variable created before
# Compute Box M test of equal covariance matrices

install.packages ("biotools")
library(biotools)
factor(grp)
boxM(Y,grp)

# Compute Hotelling T2 based on two sample data matrices

HotellingsT2(roger,adler)

# Alternative approach

alternative using a formula:

factor(grp)
HotellingsT2 (formula = Y ~ grp)


#  Compute F test for Hotelling T-squared value 
#  Enter sample sizes, number of dependent variables, and Hotelling T2 value

n1 = 3
n2 = 6
p = 2
T = 3

# Compute degrees of freedom for numerator and denominator

df1 = p
df2 = n1 + n2 - p -1

# Compute F value and p-value

Fval =  (df2/df1) * T
pval =  round(1-pf(Fval,df1,df2),digits=3)

# print out T, F, df1, df2, and p-value

cat("T = ",T,"F-value =",Fval,"df1 =",df1,"df2 =",df2," p-value=",pval,fill=FALSE,"\n")	

#  Compute a Wald test when the covariance  matrices are not homogeneous
 
W = t(m1-m2)%*%solve(s1/n1+s2/n2)%*%(m1-m2)
cat ("Wald test = ",W, fill=T)
