# Multivariate Analysis of Variance
# Stevens (2009, p. 215)



install.packages("psych")
library(psych)

stevens = matrix(c(1, 1, 13, 14,1, 1, 11, 15,1, 2, 23, 27,1, 2, 25, 29,1, 3, 32, 31,1, 3, 35, 37, 2, 1, 45, 47,2, 1, 55, 58,2, 1, 65, 63,2, 2, 75, 78,2, 2, 65, 66,2, 2, 87, 85,3, 1, 88, 85,3, 1, 91, 93, 3, 1, 24, 25,3, 1, 65, 68,3, 2, 43, 41,3, 2, 54, 53,3, 2, 65, 68,3, 2, 76, 74), ncol = 4, byrow=TRUE)
colnames(stevens) = paste("V",1:4,sep="")
rownames(stevens) = paste("S",1:20,sep="")
stevens 	#data from Stevens (2009, p. 215)

# ICC example from psych package with six ICC's from Shrout and Fleiss (1979)
# Select only ach1 and ach2 variables (V3 and V4)

ICC(stevens[,3:4])

options(scipen=999)
cor.test(stevens[,3],stevens[,4])

# Normality test

install.packages("nortest")		 # Install R nortest package
library(nortest)			   	 # Load package in library
depvar = data.frame(stevens[,3:4])	 # Select ach1 and ach2 dependent variables
names(depvar) = c("ach1","ach2")	 # Name dependent variables
attach(depvar)				 # Attach data set to use variable names

ad.test(ach1)		# Anderson-Darling
cvm.test(ach1)		# Cramer-von Mises
lillie.test(ach1)		# Kolmogorov-Smirnov
pearson.test(ach1)	# Pearson chi-square
sf.test(ach1)		# Shapiro-Francia
ad.test(ach2)	      # Anderson-Darling

cvm.test(ach2)	      # Cramer-von Mises
lillie.test(ach2)		# Kolmogorov-Smirnov
pearson.test(ach2)	# Pearson chi-square
sf.test(ach2)		# Shapiro-Francia

# Use the transposed data set, stevensT, in the shapiro.test() function.  

install.packages("mvnormtest")	# Install mvnormtest package 
library(mvnormtest)			# Load package in library
depvar = data.frame(stevens[,3:4])	# Select ach1 and ach2 dependent variables
stevensT = t(depvar)			# Transpose data set
shapiro.test(stevensT)			# Run multivariate normality test

#  The stevens data set created earlier in the chapter 	
#  Stevens (2009, p. 215) Table 8.4 Data set

method1 = stevens[1:6,3:4]	# Select method 1, ach1 and ach2
method2 = stevens[7:12,3:4] 	# Select method 2, ach1 and ach2 
method3 = stevens[13:20,3:4]		# Select method 3, ach1 and ach2

method1
method2
method3

method1cov =  cov(method1)	# Create variance-covariance matrix
method1cov

det(method1cov)                       	 # Compute determinant of matrix

method2cov = cov(method2)      # Create variance-covariance matrix
method2cov

det(method3cov)                                        # Compute determinant of matrix

# Boxt test of equal covariance matrices

install.packages("biotools")		# Install R biotools package
library(biotools)				# Load package in library
options (scipen = 999) 			# Stops scientific notation output 
factor(stevens[,1])			# Select group variable, first column is method
boxM(stevens[,3:4], stevens[,1])	# Run with dependent variables and group variable 

# Oneway analysis of variance

install.packages("MASS")       # MANOVA
install.packages("car")         # Type III SS
install.packages("psych")     # descriptive statistics
library(MASS)
library(car)
library(psych)

grp = factor(stevens[,1])		# Select group variable, first column is method
Y = (stevens[,3:4])			# Select dependent variables 
fit = manova(Y~grp)

summary(fit,test="Wilks")
summary(fit,test="Pillai")
summary(fit,test="Hotelling-Lawley")
summary(fit,test="Roy")

summary.aov(fit)

anovadata = data.frame(stevens)
names(anovadata) = c("method","class","ach1","ach2")
anovadata
describeBy(anovadata,anovadata$method)  # descriptive statistics by method


# Modified Data from Stevens (2009, p. 215) - see boldfaced numbers

stevens = matrix(c(1, 1, 13, 14,1, 1, 11, 15,1, 1, 23, 27,1, 2, 25, 29,1, 2, 32, 31,1, 2, 35, 37,
+ 2, 1, 45, 47,2, 1, 55, 58,2, 1, 65, 63,2, 2, 75, 78,2, 2, 65, 66,2, 2, 87, 85,3, 1, 88, 85,3, 1, 91, 93,
+ 3, 1, 24, 25,3, 1, 65, 68,3, 2, 43, 41,3, 2, 54, 53,3, 2, 65, 68,3, 2, 76, 74), ncol = 4, 
+ byrow=TRUE)
stevens = data.frame(stevens)
names(stevens)=c("method","class","ach1","ach2")
stevens

fit  = manova(cbind(ach1,ach2) ~ method + class + method*class, data=stevens)
summary(fit, test="Wilks")
summary(fit, test="Pillai")
summary(fit, test="Hotelling-Lawley")
summary(fit, test="Roy")

# Different Type I, Type II, and Type III Sums of Squares

fit.model1  = manova(cbind(ach1,ach2) ~ method + class + method*class, data=stevens)
summary(fit.model1, test="Wilks")

fit.model2  = manova(cbind(ach1,ach2) ~ class + method + method*class, data=stevens)
summary(fit.model2, test="Wilks")

anova(fit.model1, fit.model2)

install.packages(car)
library (car)
out = lm(cbind(ach1,ach2)~ method + class + method*class -1, data = stevens)
Manova(out,multivariate=TRUE,type = c("II"),test="Wilks")
Manova(out,multivariate=TRUE,type = c("III"),test="Wilks")

library(psych)
anovadata = data.frame(stevens)
names(anovadata) = c("method","class","ach1","ach2")
anovadata
describeBy(anovadata,anovadata$method)        # Descriptive statistics by method
describeBy(anovadata,anovadata$class)          # Descriptive statistics by class





