# Chapter 7 Multivariate Repeated Measures
# lmer4 package example
# person-period data set

# mydata file converted to a person-period data set

install.packages ("reshape")
library (reshape)

mydata2 = mydata[,c(1,3:10)]     # Drop subject number from the data set
ppmydata = melt(mydata2,id = "group",measured=c("slope1","intrcpt1","slope2","intrcpt2","slope3", "intrcpt3", "slope4","intrcpt4"))
attach(mydata)

head(ppmydata, n = 20)             # print first 20 records

# Add id and time to data set

time = cbind(rep(c(1:4),c(40,40,40,40)))
id = cbind(rep(c(1:20),c(8)))
ppmydata = data.frame(cbind(id,ppmydata,time))
attach(ppmydata)
head(ppmydata,n=20)         #  check data set

# Run lmer4 analysis

install.packages("lmer4")
library(lme4)

lmer.ppout = lmer(value ~ group + time + group*time + (1|id), data=ppmydata)
anova(lmer.ppout)

# Calculate p values

pgroup = 1 - pf(.4035,1,159)  
pgroup
ptime = 1 - pf(3.0606,1,159)  
ptime
pgroup.time = 1 - pf(.2669,1,159)  
pgroup.time

#  Intercept model
# data set with intercepts

myintrcpt = ppmydata[c(21:40,61:80,101:120,141:160),]     
lmer.intr = lmer(value~group + time + group*time+ (1|id), data = myintrcpt)
anova(lmer.intr) 

# interpret the interaction effect.

options(scipen=999)
pgroup = 1 - pf(44.573,1,159)  
ptime = 1 - pf(133.699,1,159)  
pgroup.time = 1 - pf(78.605,1,159)  

# Print p values

pgroup
ptime
pgroup.time

# Slope model

myslope = ppmydata[c(1:20,41:60,81:100,121:140),]

lmer.pps = lmer(value~group + time + group*time+ (1|id), data = myslope)
anova(lmer.pps)

pgroup = 1 - pf(.5906,1,159)
ptime = 1 - pf(13.4538,1,159)  
pgroup.time = 1 - pf(.0267,1,159)  

# Print p values

pgroup
ptime
pgroup.time


